
;**************************************************************************
;*                    I2C teplomer                                        *
;**************************************************************************
;**************************************************************************
;*          v 1.06 - 12.04.2013                                           *
;**************************************************************************
;*          Hardw.: PIC16F887 used                                        *
;*          TI TMP100 temperature sensore used                            *
;*          19 LEDs indicates the temperature: 13 - 31C                 *
;*          OSC.......: Internal osc. used     POWER.....:   5V extern.   *
;**************************************************************************


;7 yellow LEDs: 13 - 19C
;6 green LEDs : 20 - 25C
;6 red LEDs   : 26 - 31C


;	SDA -- SDA (RC4)
;	SCL -- SCL (RC3)

;keyboard
;	kbdclk  -- RB0
;	kbddata -- RB1


 INCLUDE "P16F887.INC"


_U001			     EQU     B'1110000011000100'	;see Page 206 of Datasheet
_U002			     EQU     B'1111111111111111'	;see Page 207 of Datasheet

;	__CONFIG	_CONFIG1, _DEBUG_OFF & _PLL_EN & _BORV_2_5 & _BOR_OFF & _CP_OFF & _MCLR_DIS & _PWRT_DIS & _WDT_OFF & _INTRC_OSC_NOCLKOUT
;	__CONFIG	_CONFIG2, _VCAP_DIS


	__CONFIG	_CONFIG1, _U001

	__CONFIG	_CONFIG2, _U002


;==========================================================================
;       Variable Definition
;==========================================================================
TIMER1		EQU	H'20'		;delay routine
TIMER2		EQU	H'21'		; "	"	"

;interrupt
W_TEMP		EQU	H'22'
STATUS_TEMP	EQU	H'23'
PCLATH_TEMP	EQU	H'24'
data_tmp	EQU	H'25'
bus_D		EQU	H'26'
cnt1		EQU	H'27'
cnt2		EQU	H'28'
cnt3		EQU	H'29'
kbd_cnt1	EQU	H'2A'
kbd_buffer	EQU	H'2B'		;keyboard byte buffer
kbd_bb		EQU	H'2c'		;keyboard bit buffer
disp_pos	EQU	H'2D'
c_tmp		EQU	H'2E'

v_vt		EQU	H'2F'
v_tst1		EQU	H'30'		;temperature - char output 1
v_tst2		EQU	H'31'		;temperature - char output 2
v_tst3		EQU	H'32'		;temperature - char output 3

v_too_low	EQU	H'33'		;temperature is too low  ( < 13)
v_too_high	EQU	H'34'		;temperature is too high ( > 31)

v_blink		EQU	H'36'
v_off		EQU	H'37'



;
vs_d0		EQU	H'4A'
vs_d1		EQU	H'4B'
vs_d2		EQU	H'4C'
vs_d3		EQU	H'4D'
;
kbd_out		EQU	H'4E'
kbd_parity	EQU	H'4F'

b_ax		EQU	H'50'
tmp_ot		EQU	H'51'

s_eeprom	EQU	H'52'





v_byte		EQU	H'5B'		;data to be written to PCF8574
v_temp1		EQU	H'5C'		;temperature from TMP100 (MSB)
v_temp2		EQU	H'5D'		;temperature from TMP100 (LSB)

v_tempx		EQU	H'5E'		;temperature in dec
v_LED1		EQU	H'5F'		;temperature for first 8 LEDs
v_LED2		EQU	H'60'		;temperature for next 8 LEDs
v_LED3		EQU	H'61'		;temperature for last 3 LEDs
;==========================================================================

		ORG	0		;Reset vector address
		GOTO	RESET		;goto RESET routine when boot.

;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
;----------------------------------------------------------------------------
; INTERRUPT SERVICE ROUTINE -------------------------------------------------
;----------------------------------------------------------------------------
;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX

		ORG	004
;save important variables
		MOVWF	W_TEMP			;Copy W to W_TEMP register
		SWAPF	STATUS,W		;Swap status to be saved into W

;Swaps are used because they do not affect the status bits

		BANKSEL	STATUS_TEMP		;Select regardless of current bank
		MOVWF	STATUS_TEMP		;Copy status to bank zero STATUS_TEMP register
		MOVF	PCLATH,W		;Copy PCLATH to W register
		MOVWF	PCLATH_TEMP		;Copy W register to PCLATH_TEMP

		bcf	INTCON,GIE

		PAGESEL	PAGE0

		goto	int_serv
;----------------------------------------------------------------------------
;----------------------------------------------------------------------------
;
;	       **********************************
;              **  RESET :  main boot routine  **
;              **********************************

RESET		nop
PAGE0
;
		BSF	STATUS,RP0	;Switch to register bank 1
		MOVLW	B'01011111'	;Set PIC options (See datasheet).
		MOVWF	OPTION_REG	;Write the OPTION register.
		bcf	OPTION_REG,T0CS	;set-up TIMER0 as timer
		bsf	OPTION_REG,PSA	;prescaler NOT for TIMER0
		;
		CLRF	INTCON		;Disable interrupts
		clrf	IOCB
		bsf	IOCB,D'000'	;enable interrupt on change for RB0 only

		MOVLW	B'11000000'	;PORTA
		MOVWF	TRISA

		MOVLW	B'00000000'	;PORTB
		MOVWF	TRISB

		MOVLW	B'00011000'	;PORTC
		MOVWF	TRISC

		MOVLW	B'00000000'	;PORTD
		MOVWF	TRISD

		MOVLW	B'11111000'	;PORTE = output; RE3 = input
		MOVWF	TRISE

		movlw	B'00000011'
		movwf	WPUB

		bsf	STATUS,RP0
		bsf	STATUS,RP1
		clrf	ANSEL
		clrf	ANSELH

		bcf	STATUS,RP0	;Switch Back to reg. Bank 0
		bcf	STATUS,RP1

;----------------------------------------------------------------------------
;set up I2C BUS for communication as a master
		movlw	B'00101000'		;see Datasheet Page 177
;			bit 3-0 SSPM<3:0>: Synchronous Serial Port Mode Select bits
;			1000 = I2C Master mode, clock = FOSC / (4 * (SSPADD+1))
		movwf	SSPCON

;----------------------------------------------------------------------------

; XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
; XXXXXXXXXX       start-up        XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
; XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX

		call	demo01

;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
;-----------------------------------------------------------------------------
;                   TMP100       temperature measurement
;-----------------------------------------------------------------------------
;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
tmp100_m	nop

		movlw	'-'
		movwf	v_tst1
		movwf	v_tst2
		movwf	v_tst3

		movlw	D'001'
		movwf	v_blink
		clrf	v_off

tmp100_rt	call	tmp100_read_t1
		call	t_convert2dec
		call	bt_LEDs			;convert v_tempx to "LED format"

		btfsc	v_too_high,D'000'
		goto	tmp_disp_th		;temperature too high
		btfsc	v_too_low,D'000'
		goto	tmp_disp_tl		;temperature too low

tmp_disp_std	movf	v_LED1,0
		movwf	PORTB
		movf	v_LED2,0
		movwf	PORTD
		movf	v_LED3,0
		movwf	PORTE

		call	d2_long
		goto	tmp100_rt
;------------------------------------------
tmp_disp_th	clrf	PORTB
		clrf	PORTD
		movlw	B'00000011'
		movwf	PORTE
		goto	tmp_blink

;------------------------------------------
tmp_disp_tl	clrf	PORTE
		clrf	PORTD
		movlw	B'11000000'
		movwf	PORTB

tmp_blink	nop
		decfsz	v_blink,1
		goto	v_n3
		movlw	D'001'
		movwf	v_blink

		btfss	v_off,D'000'
		goto	set_off
		clrf	v_off
		goto	v_n3
;
set_off		movlw	D'255'
		movwf	v_off
;
v_n3		btfsc	v_off,D'00'
		goto	tmp_LED_off

v_n99		call	d2_long
		goto	tmp100_rt

;---------------------------------------------
tmp_LED_off	clrf	PORTB
		clrf	PORTD
		clrf	PORTE

		goto	v_n99
;-----------------------------------------------------------------------------
;-----------------------------------------------------------------------------
t_convert2dec	movlw	'0'
		movwf	v_tst1
		movwf	v_tst2
		movwf	v_tst3
;
		clrf	v_tempx

		bsf	v_too_low,D'000'
		clrf	v_too_high
;
		incf	v_temp1,0		;we convert only MSB now
		movwf	TIMER1			;store "to be converted" value to data location TIMER1
		
t_next		decfsz	TIMER1,1
		goto	t_inc_t
;we are done.....----
		movf	v_tst1,0
		xorlw	'0'
		btfss	STATUS,Z
		return
;
		movlw	' '		;use space instead of very first '0'
		movwf	v_tst1

		return
;---------------------
t_inc_t		nop

		incf	v_tempx,1

		movf	v_tempx,0
		xorlw	D'032'
		btfsc	STATUS,Z
		bsf	v_too_high,D'000'		;temperature is already 32...

		movf	v_tempx,0
		xorlw	D'013'
		btfsc	STATUS,Z
		clrf	v_too_low			;we reached 13 already...

		incf	v_tst3,1
		movf	v_tst3,0
		xorlw	':'
		btfss	STATUS,Z
		goto	t_c_fin
;
		movlw	'0'
		movwf	v_tst3
		incf	v_tst2,1
		movf	v_tst2,0
		xorlw	':'
		btfss	STATUS,Z
		goto	t_c_fin
;
		movlw	'0'
		movwf	v_tst2
		incf	v_tst1,1

		goto	t_next
;-----------------------------------
t_c_fin		nop		
		goto	t_next
;-----------------------------------------------------------------------------
;xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
;xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
;xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
;
; I2C communication routines
;
;xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
;xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
;xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx

;-----------------------------------------------------------------------------
;-----------------------------------------------------------------------------
; TMP100 I2C communication routines
;-----------------------------------------------------------------------------
;-----------------------------------------------------------------------------
tmp100_read_t1	nop

		bsf	STATUS,RP0
		movlw	B'00111111'
		movwf	SSPADD
		clrf	SSPSTAT
		bcf	STATUS,RP0

;1st step - address preparation - not important here / not used
		bcf	PORTA,D'000'		;A0 = 0
		bcf	PORTA,D'001'		;A1 = 0
		bcf	PORTA,D'002'		;A2 = 0

;2nd step - Start condition
		bsf	STATUS,RP0
		bsf	SSPCON2, SEN
		bcf	STATUS,RP0

		call	d55
		bcf	PIR1, SSPIF
;
;Step 3: addressing the TMP100 device

		movlw	B'10010100'		;TMP100 = 1001; A1 = 0 (hard wired); A0 = 1 (hard wired) => add: 010 ; R/-W = 0 (write)
		movwf	SSPBUF

		btfsc	SSPCON,WCOL
		nop

		bcf	PIR1, SSPIF
		call	d55
		bcf	PIR1, SSPIF

;Step 4 - write data to the pointer register
		movlw	B'00000000'			;last two bits = 00 => temperature register
		movwf	SSPBUF

		btfsc	SSPCON,WCOL
		nop

		bcf	PIR1, SSPIF
		call	d55
		bcf	PIR1, SSPIF

;Step 5 - 2nd Start condition
		bsf	STATUS,RP0
		bsf	SSPCON2, SEN
		bcf	STATUS,RP0

		call	d55
		bcf	PIR1, SSPIF
;
;Step 6: addressing the TMP100 device

		movlw	B'10010101'		;TMP100 = 1001; A1 = 0 (hard wired); A0 = 1 (hard wired) => add: 010 ; R/-W = 1 (read)
		movwf	SSPBUF

		btfsc	SSPCON,WCOL
		nop

		bcf	PIR1, SSPIF
		call	d55
		bcf	PIR1, SSPIF

;Step 7: read MSB byte of T-high

		bsf	STATUS,RP0
		bsf	SSPCON2, RCEN
		bcf	STATUS,RP0
		
		call	d55
		bcf	PIR1, SSPIF

		movf	SSPBUF,0		;received byte
		movwf	v_temp1
;
		call	d55
		bcf	PIR1, SSPIF
;
		bsf	STATUS,RP0
		bcf	SSPCON2, ACKDT		;ACK
		bsf	SSPCON2, ACKEN
		bcf	STATUS,RP0
		
		call	d55
		bcf	PIR1, SSPIF


;Step 8: read LSB byte of T-high

		bsf	STATUS,RP0
		bsf	SSPCON2, RCEN
		bcf	STATUS,RP0
		
		call	d55
		bcf	PIR1, SSPIF

		movf	SSPBUF,0		;received byte
		movwf	v_temp2
;
		call	d55
		bcf	PIR1, SSPIF
;
		bsf	STATUS,RP0
		bsf	SSPCON2, ACKDT		;NACK
		bsf	SSPCON2, ACKEN
		bcf	STATUS,RP0
		
		call	d55
		bcf	PIR1, SSPIF

;Step 9: send STOP condition
		bsf	STATUS,RP0
		bsf	SSPCON2, PEN
		bcf	STATUS,RP0
		
		bcf	PIR1, SSPIF

		call	d55

		return

;--------------------------------------------------------------------------
;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
;		*********************************************
;		*               delay routine               *
;		*********************************************
;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
;--------------------------------------------------------------------------

d2		MOVLW   D'255'
		MOVWF   TIMER2
DEL_LOOP1	MOVLW   D'255'
		MOVWF   TIMER1

DEL_LOOP2	DECFSZ  TIMER1,F
		GOTO    DEL_LOOP2
		DECFSZ  TIMER2,F
		GOTO    DEL_LOOP1
		return
;------------------------------------
;------------------------------------
d2_long		call	d2
		return
;------------------------------------
;------------------------------------
dr2		MOVLW   D'060'
		MOVWF   TIMER2
DEL_LOOP1a	MOVLW   D'255'
		MOVWF   TIMER1

DEL_LOOP2a	DECFSZ  TIMER1,F
		GOTO    DEL_LOOP2a
		DECFSZ  TIMER2,F
		GOTO    DEL_LOOP1a
		return
;-----------------------------------------------------------------------------
d55		movlw	D'255'
		movwf	TIMER2
d55_loop	decfsz	TIMER2,F
		goto	d55_loop
		return
;-----------------------------------------------------------------------------
;-----------------------------------------------------------------------------
;-----------------------------------------------------------------------------
;-----------------------------------------------------------------------------
;-----------------------------------------------------------------------------
t_LEDs		nop

		clrf	v_LED1
		clrf	v_LED2
		clrf	v_LED3

		movf	v_tempx,0
		xorlw	D'013'
		btfsc	STATUS,Z
		goto	t_LED11

		movf	v_tempx,0
		xorlw	D'014'
		btfsc	STATUS,Z
		goto	t_LED12

		movf	v_tempx,0
		xorlw	D'015'
		btfsc	STATUS,Z
		goto	t_LED13

		movf	v_tempx,0
		xorlw	D'016'
		btfsc	STATUS,Z
		goto	t_LED14

		movf	v_tempx,0
		xorlw	D'017'
		btfsc	STATUS,Z
		goto	t_LED15

		movf	v_tempx,0
		xorlw	D'018'
		btfsc	STATUS,Z
		goto	t_LED16

		movf	v_tempx,0
		xorlw	D'019'
		btfsc	STATUS,Z
		goto	t_LED17

		movf	v_tempx,0
		xorlw	D'020'
		btfsc	STATUS,Z
		goto	t_LED18

		movf	v_tempx,0
		xorlw	D'021'
		btfsc	STATUS,Z
		goto	t_LED19


		movf	v_tempx,0
		xorlw	D'022'
		btfsc	STATUS,Z
		goto	t_LED20

		movf	v_tempx,0
		xorlw	D'023'
		btfsc	STATUS,Z
		goto	t_LED21

		movf	v_tempx,0
		xorlw	D'024'
		btfsc	STATUS,Z
		goto	t_LED22

		movf	v_tempx,0
		xorlw	D'025'
		btfsc	STATUS,Z
		goto	t_LED23

		movf	v_tempx,0
		xorlw	D'026'
		btfsc	STATUS,Z
		goto	t_LED24

		movf	v_tempx,0
		xorlw	D'027'
		btfsc	STATUS,Z
		goto	t_LED25

		movf	v_tempx,0
		xorlw	D'028'
		btfsc	STATUS,Z
		goto	t_LED26

		movf	v_tempx,0
		xorlw	D'029'
		btfsc	STATUS,Z
		goto	t_LED27

		movf	v_tempx,0
		xorlw	D'030'
		btfsc	STATUS,Z
		goto	t_LED28

		movf	v_tempx,0
		xorlw	D'031'
		btfsc	STATUS,Z
		goto	t_LED29

;error

		movf	v_temp1,0
		movwf	v_LED1
		movf	v_temp2,0
		movwf	v_LED2
		movlw	B'00000011'
		movwf	v_LED3

		return
;-----------------------------------------------------------------------------
;-----------------------------------------------------------------------------
bt_LEDs		nop

		clrf	v_LED1
		clrf	v_LED2
		clrf	v_LED3

		movf	v_tempx,0
		xorlw	D'013'
		btfsc	STATUS,Z
		goto	bt_LED11

		movf	v_tempx,0
		xorlw	D'014'
		btfsc	STATUS,Z
		goto	bt_LED12

		movf	v_tempx,0
		xorlw	D'015'
		btfsc	STATUS,Z
		goto	bt_LED13

		movf	v_tempx,0
		xorlw	D'016'
		btfsc	STATUS,Z
		goto	bt_LED14

		movf	v_tempx,0
		xorlw	D'017'
		btfsc	STATUS,Z
		goto	bt_LED15

		movf	v_tempx,0
		xorlw	D'018'
		btfsc	STATUS,Z
		goto	bt_LED16

		movf	v_tempx,0
		xorlw	D'019'
		btfsc	STATUS,Z
		goto	bt_LED17

		movf	v_tempx,0
		xorlw	D'020'
		btfsc	STATUS,Z
		goto	bt_LED18

		movf	v_tempx,0
		xorlw	D'021'
		btfsc	STATUS,Z
		goto	bt_LED19


		movf	v_tempx,0
		xorlw	D'022'
		btfsc	STATUS,Z
		goto	bt_LED20

		movf	v_tempx,0
		xorlw	D'023'
		btfsc	STATUS,Z
		goto	bt_LED21

		movf	v_tempx,0
		xorlw	D'024'
		btfsc	STATUS,Z
		goto	bt_LED22

		movf	v_tempx,0
		xorlw	D'025'
		btfsc	STATUS,Z
		goto	bt_LED23

		movf	v_tempx,0
		xorlw	D'026'
		btfsc	STATUS,Z
		goto	bt_LED24

		movf	v_tempx,0
		xorlw	D'027'
		btfsc	STATUS,Z
		goto	bt_LED25

		movf	v_tempx,0
		xorlw	D'028'
		btfsc	STATUS,Z
		goto	bt_LED26

		movf	v_tempx,0
		xorlw	D'029'
		btfsc	STATUS,Z
		goto	bt_LED27

		movf	v_tempx,0
		xorlw	D'030'
		btfsc	STATUS,Z
		goto	bt_LED28

		movf	v_tempx,0
		xorlw	D'031'
		btfsc	STATUS,Z
		goto	bt_LED29

;error

		movf	v_temp1,0
		movwf	v_LED1
		movf	v_temp2,0
		movwf	v_LED2
		movlw	B'00000011'
		movwf	v_LED3

		return
;-------------------------------------------------
;-------------------------------------------------
;-------------------------------------------------
t_LED11		movlw	B'10000000'
		movwf	v_LED1
		clrf	v_LED2
		clrf	v_LED3
		return

t_LED12		movlw	B'01000000'
		movwf	v_LED1
		clrf	v_LED2
		clrf	v_LED3
		return

t_LED13		movlw	B'00100000'
		movwf	v_LED1
		clrf	v_LED2
		clrf	v_LED3
		return

t_LED14		movlw	B'00010000'
		movwf	v_LED1
		clrf	v_LED2
		clrf	v_LED3
		return

t_LED15		movlw	B'00001000'
		movwf	v_LED1
		clrf	v_LED2
		clrf	v_LED3
		return

t_LED16		movlw	B'00000100'
		movwf	v_LED1
		clrf	v_LED2
		clrf	v_LED3
		return

t_LED17		movlw	B'00000010'
		movwf	v_LED1
		clrf	v_LED2
		clrf	v_LED3
		return

t_LED18		movlw	B'00000001'
		movwf	v_LED1
		clrf	v_LED2
		clrf	v_LED3
		return

t_LED19		movlw	B'10000000'
		movwf	v_LED2
		clrf	v_LED1
		clrf	v_LED3
		return

t_LED20		movlw	B'01000000'
		movwf	v_LED2
		clrf	v_LED1
		clrf	v_LED3
		return

t_LED21		movlw	B'00100000'
		movwf	v_LED2
		clrf	v_LED1
		clrf	v_LED3
		return

t_LED22		movlw	B'00010000'
		movwf	v_LED2
		clrf	v_LED1
		clrf	v_LED3
		return

t_LED23		movlw	B'00001000'
		movwf	v_LED2
		clrf	v_LED1
		clrf	v_LED3
		return

t_LED24		movlw	B'00000100'
		movwf	v_LED2
		clrf	v_LED1
		clrf	v_LED3
		return

t_LED25		movlw	B'00000010'
		movwf	v_LED2
		clrf	v_LED1
		clrf	v_LED3
		return

t_LED26		movlw	B'00000001'
		movwf	v_LED2
		clrf	v_LED1
		clrf	v_LED3
		return

t_LED27		movlw	B'00000100'
		movwf	v_LED3
		clrf	v_LED1
		clrf	v_LED2
		return

t_LED28		movlw	B'00000010'
		movwf	v_LED3
		clrf	v_LED1
		clrf	v_LED2
		return

t_LED29		movlw	B'00000001'
		movwf	v_LED3
		clrf	v_LED1
		clrf	v_LED2
		return
;-----------------------------------------------------------------------------
;-----------------------------------------------------------------------------
bt_LED11	movlw	B'10000000'
		movwf	v_LED1
		clrf	v_LED2
		clrf	v_LED3
		return

bt_LED12	movlw	B'11000000'
		movwf	v_LED1
		clrf	v_LED2
		clrf	v_LED3
		return

bt_LED13	movlw	B'11100000'
		movwf	v_LED1
		clrf	v_LED2
		clrf	v_LED3
		return

bt_LED14	movlw	B'11110000'
		movwf	v_LED1
		clrf	v_LED2
		clrf	v_LED3
		return

bt_LED15	movlw	B'11111000'
		movwf	v_LED1
		clrf	v_LED2
		clrf	v_LED3
		return

bt_LED16	movlw	B'11111100'
		movwf	v_LED1
		clrf	v_LED2
		clrf	v_LED3
		return

bt_LED17	movlw	B'11111110'
		movwf	v_LED1
		clrf	v_LED2
		clrf	v_LED3
		return

bt_LED18	movlw	B'11111111'
		movwf	v_LED1
		clrf	v_LED2
		clrf	v_LED3
		return

bt_LED19	movlw	B'10000000'
		movwf	v_LED2
		movlw	B'11111111'
		movwf	v_LED1
		clrf	v_LED3
		return

bt_LED20	movlw	B'11000000'
		movwf	v_LED2
		movlw	B'11111111'
		movwf	v_LED1
		clrf	v_LED3
		return

bt_LED21	movlw	B'11100000'
		movwf	v_LED2
		movlw	B'11111111'
		movwf	v_LED1
		clrf	v_LED3
		return

bt_LED22	movlw	B'11110000'
		movwf	v_LED2
		movlw	B'11111111'
		movwf	v_LED1
		clrf	v_LED3
		return

bt_LED23	movlw	B'11111000'
		movwf	v_LED2
		movlw	B'11111111'
		movwf	v_LED1
		clrf	v_LED3
		return

bt_LED24	movlw	B'11111100'
		movwf	v_LED2
		movlw	B'11111111'
		movwf	v_LED1
		clrf	v_LED3
		return

bt_LED25	movlw	B'11111110'
		movwf	v_LED2
		movlw	B'11111111'
		movwf	v_LED1
		clrf	v_LED3
		return

bt_LED26	movlw	B'11111111'
		movwf	v_LED2
		movlw	B'11111111'
		movwf	v_LED1
		clrf	v_LED3
		return

bt_LED27	movlw	B'00000100'
		movwf	v_LED3
		movlw	B'11111111'
		movwf	v_LED1
		movwf	v_LED2
		return

bt_LED28	movlw	B'00000110'
		movwf	v_LED3
		movlw	B'11111111'
		movwf	v_LED1
		movwf	v_LED2
		return

bt_LED29	movlw	B'00000111'
		movwf	v_LED3
		movlw	B'11111111'
		movwf	v_LED1
		movwf	v_LED2
		return
;-----------------------------------------------------------------------------
;-----------------------------------------------------------------------------

demo01		clrf	PORTD
		clrf	PORTB
		clrf	PORTE

		bsf	PORTB,D'007'
		call	dr2
		bsf	PORTB,D'006'
		call	dr2
		bsf	PORTB,D'005'
		call	dr2
		bsf	PORTB,D'004'
		call	dr2
		bsf	PORTB,D'003'
		call	dr2
		bsf	PORTB,D'002'
		call	dr2
		bsf	PORTB,D'001'
		call	dr2
		bsf	PORTB,D'000'
		call	dr2
		bsf	PORTD,D'007'
		call	dr2
		bsf	PORTD,D'006'
		call	dr2
		bsf	PORTD,D'005'
		call	dr2
		bsf	PORTD,D'004'
		call	dr2
		bsf	PORTD,D'003'
		call	dr2
		bsf	PORTD,D'002'
		call	dr2
		bsf	PORTD,D'001'
		call	dr2
		bsf	PORTD,D'000'
		call	dr2
		bsf	PORTE,D'002'
		call	dr2
		bsf	PORTE,D'001'
		call	dr2
		bsf	PORTE,D'000'
		call	dr2
;
		bcf	PORTB,D'007'
		call	dr2
		bcf	PORTB,D'006'
		call	dr2
		bcf	PORTB,D'005'
		call	dr2
		bcf	PORTB,D'004'
		call	dr2
		bcf	PORTB,D'003'
		call	dr2
		bcf	PORTB,D'002'
		call	dr2
		bcf	PORTB,D'001'
		call	dr2
		bcf	PORTB,D'000'
		call	dr2
		bcf	PORTD,D'007'
		call	dr2
		bcf	PORTD,D'006'
		call	dr2
		bcf	PORTD,D'005'
		call	dr2
		bcf	PORTD,D'004'
		call	dr2
		bcf	PORTD,D'003'
		call	dr2
		bcf	PORTD,D'002'
		call	dr2
		bcf	PORTD,D'001'
		call	dr2
		bcf	PORTD,D'000'
		call	dr2
		bcf	PORTE,D'002'
		call	dr2
		bcf	PORTE,D'001'
		call	dr2
		bcf	PORTE,D'000'
		call	dr2

;-----------------------------------------------------------------------------

		clrf	PORTD
		clrf	PORTB
		clrf	PORTE

		return
;-----------------------------------------------------------------------------
;-----------------------------------------------------------------------------
;-----------------------------------------------------------------------------

int_serv	nop
		nop
		nop

		bcf	PIR1, SSPIF

;restore values
		BANKSEL STATUS_TEMP	;Select regardless of current bank
		MOVF PCLATH_TEMP,W	;
		MOVWF PCLATH		;Restore PCLATH
		SWAPF STATUS_TEMP,W	;Swap STATUS_TEMP register into W
					;(sets bank to original state)
		MOVWF STATUS		;Move W into STATUS register
		SWAPF W_TEMP,F		;Swap W_TEMP
		SWAPF W_TEMP,W		;Swap W_TEMP into W


		bsf	INTCON,GIE
		bsf	INTCON,PEIE

		bsf	PIE1,SSPIE
		retfie


;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX

		END